aboutsummaryrefslogtreecommitdiffstats
path: root/lib/Target/PowerPC/PPCISelLowering.h
diff options
context:
space:
mode:
authorNate Begeman <natebegeman@mac.com>2005-09-06 22:03:27 +0000
committerNate Begeman <natebegeman@mac.com>2005-09-06 22:03:27 +0000
commitc09eeec0ebc378644bafd04916e5efafa7d98152 (patch)
treed78613977511e6d8bfc0da57a58164ea62430d2b /lib/Target/PowerPC/PPCISelLowering.h
parent46a780056b4b8a76773836a05b3f64f0781b2622 (diff)
downloadexternal_llvm-c09eeec0ebc378644bafd04916e5efafa7d98152.zip
external_llvm-c09eeec0ebc378644bafd04916e5efafa7d98152.tar.gz
external_llvm-c09eeec0ebc378644bafd04916e5efafa7d98152.tar.bz2
Implement i64<->fp using the fctidz/fcfid instructions on PowerPC when we
are allowed to generate 64-bit-only PowerPC instructions for 32 bit hosts, such as the PowerPC 970. This speeds up 189.lucas from 81.99 to 32.64 seconds. git-svn-id: https://llvm.org/svn/llvm-project/llvm/trunk@23250 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'lib/Target/PowerPC/PPCISelLowering.h')
-rw-r--r--lib/Target/PowerPC/PPCISelLowering.h12
1 files changed, 9 insertions, 3 deletions
diff --git a/lib/Target/PowerPC/PPCISelLowering.h b/lib/Target/PowerPC/PPCISelLowering.h
index 924a672..eecbfda 100644
--- a/lib/Target/PowerPC/PPCISelLowering.h
+++ b/lib/Target/PowerPC/PPCISelLowering.h
@@ -29,9 +29,15 @@ namespace llvm {
///
FSEL,
- /// FCTIWZ - The FCTIWZ instruction, taking an f32 or f64 operand,
- /// producing an f64 value.
- FCTIWZ,
+ /// FCFID - The FCFID instruction, taking an f64 operand and producing
+ /// and f64 value containing the FP representation of the integer that
+ /// was temporarily in the f64 operand.
+ FCFID,
+
+ /// FCTI[D,W]Z - The FCTIDZ and FCTIWZ instructions, taking an f32 or f64
+ /// operand, producing an f64 value containing the integer representation
+ /// of that FP value.
+ FCTIDZ, FCTIWZ,
};
}